from typing import Any

import proto

from google.ads.googleads.v7.common.types import (
    criteria as criteria,
    extensions as extensions,
)
from google.ads.googleads.v7.enums.types import (
    keyword_match_type as keyword_match_type,
    recommendation_type as recommendation_type,
    target_cpa_opt_in_recommendation_goal as target_cpa_opt_in_recommendation_goal,
)

__protobuf__: Any

class Recommendation(proto.Message):
    class RecommendationImpact(proto.Message):
        base_metrics: Any
        potential_metrics: Any
    class RecommendationMetrics(proto.Message):
        impressions: Any
        clicks: Any
        cost_micros: Any
        conversions: Any
        video_views: Any
    class CampaignBudgetRecommendation(proto.Message):
        class CampaignBudgetRecommendationOption(proto.Message):
            budget_amount_micros: Any
            impact: Any
        current_budget_amount_micros: Any
        recommended_budget_amount_micros: Any
        budget_options: Any
    class KeywordRecommendation(proto.Message):
        keyword: Any
        recommended_cpc_bid_micros: Any
    class SearchPartnersOptInRecommendation(proto.Message): ...
    class MaximizeClicksOptInRecommendation(proto.Message):
        recommended_budget_amount_micros: Any
    class TextAdRecommendation(proto.Message):
        ad: Any
        creation_date: Any
        auto_apply_date: Any
    class TargetCpaOptInRecommendation(proto.Message):
        class TargetCpaOptInRecommendationOption(proto.Message):
            goal: Any
            target_cpa_micros: Any
            required_campaign_budget_amount_micros: Any
            impact: Any
        options_: Any
        recommended_target_cpa_micros: Any
    class MaximizeConversionsOptInRecommendation(proto.Message):
        recommended_budget_amount_micros: Any
    class OptimizeAdRotationRecommendation(proto.Message): ...
    class ResponsiveSearchAdRecommendation(proto.Message):
        ad: Any
    class EnhancedCpcOptInRecommendation(proto.Message): ...
    class TargetRoasOptInRecommendation(proto.Message):
        recommended_target_roas: Any
        required_campaign_budget_amount_micros: Any
    class CalloutExtensionRecommendation(proto.Message):
        recommended_extensions: Any
    class SitelinkExtensionRecommendation(proto.Message):
        recommended_extensions: Any
    class CallExtensionRecommendation(proto.Message):
        recommended_extensions: Any
    class KeywordMatchTypeRecommendation(proto.Message):
        keyword: Any
        recommended_match_type: Any
    class MoveUnusedBudgetRecommendation(proto.Message):
        excess_campaign_budget: Any
        budget_recommendation: Any
    resource_name: Any
    type_: Any
    impact: Any
    campaign_budget: Any
    campaign: Any
    ad_group: Any
    dismissed: Any
    campaign_budget_recommendation: Any
    forecasting_campaign_budget_recommendation: Any
    keyword_recommendation: Any
    text_ad_recommendation: Any
    target_cpa_opt_in_recommendation: Any
    maximize_conversions_opt_in_recommendation: Any
    enhanced_cpc_opt_in_recommendation: Any
    search_partners_opt_in_recommendation: Any
    maximize_clicks_opt_in_recommendation: Any
    optimize_ad_rotation_recommendation: Any
    callout_extension_recommendation: Any
    sitelink_extension_recommendation: Any
    call_extension_recommendation: Any
    keyword_match_type_recommendation: Any
    move_unused_budget_recommendation: Any
    target_roas_opt_in_recommendation: Any
    responsive_search_ad_recommendation: Any
    marginal_roi_campaign_budget_recommendation: Any



from typing import Any

import proto

__protobuf__: Any

class AgeRangeTypeEnum(proto.Message):
    class AgeRangeType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        AGE_RANGE_18_24: int
        AGE_RANGE_25_34: int
        AGE_RANGE_35_44: int
        AGE_RANGE_45_54: int
        AGE_RANGE_55_64: int
        AGE_RANGE_65_UP: int
        AGE_RANGE_UNDETERMINED: int



from typing import Any

import proto

__protobuf__: Any

class ParentalStatusTypeEnum(proto.Message):
    class ParentalStatusType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PARENT: int
        NOT_A_PARENT: int
        UNDETERMINED: int



from typing import Any

import proto
from google.protobuf import field_mask_pb2 as field_mask_pb2

from google.ads.googleads.v8.resources.types import (
    merchant_center_link as merchant_center_link,
)

__protobuf__: Any

class ListMerchantCenterLinksRequest(proto.Message):
    customer_id: Any

class ListMerchantCenterLinksResponse(proto.Message):
    merchant_center_links: Any

class GetMerchantCenterLinkRequest(proto.Message):
    resource_name: Any

class MutateMerchantCenterLinkRequest(proto.Message):
    customer_id: Any
    operation: Any
    validate_only: Any

class MerchantCenterLinkOperation(proto.Message):
    update_mask: Any
    update: Any
    remove: Any

class MutateMerchantCenterLinkResponse(proto.Message):
    result: Any

class MutateMerchantCenterLinkResult(proto.Message):
    resource_name: Any



from typing import Any

import proto

__protobuf__: Any

class AppStoreEnum(proto.Message):
    class AppStore(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        APPLE_ITUNES: int
        GOOGLE_PLAY: int



from typing import Any

import proto

__protobuf__: Any

class AdNetworkTypeEnum(proto.Message):
    class AdNetworkType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        SEARCH: int
        SEARCH_PARTNERS: int
        CONTENT: int
        YOUTUBE_SEARCH: int
        YOUTUBE_WATCH: int
        MIXED: int



from typing import Any

import proto

__protobuf__: Any

class ConversionValueRuleSetErrorEnum(proto.Message):
    class ConversionValueRuleSetError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CONFLICTING_VALUE_RULE_CONDITIONS: int
        INVALID_VALUE_RULE: int
        DIMENSIONS_UPDATE_ONLY_ALLOW_APPEND: int
        CONDITION_TYPE_NOT_ALLOWED: int
        DUPLICATE_DIMENSIONS: int
        INVALID_CAMPAIGN_ID: int
        CANNOT_PAUSE_UNLESS_ALL_VALUE_RULES_ARE_PAUSED: int
        SHOULD_PAUSE_WHEN_ALL_VALUE_RULES_ARE_PAUSED: int
        VALUE_RULES_NOT_SUPPORTED_FOR_CAMPAIGN_TYPE: int



from typing import Any

import proto
from google.protobuf import field_mask_pb2 as field_mask_pb2

__protobuf__: Any

class GetCustomerRequest(proto.Message):
    resource_name: Any

class MutateCustomerRequest(proto.Message):
    customer_id: Any
    operation: Any
    validate_only: Any
    response_content_type: Any

class CreateCustomerClientRequest(proto.Message):
    customer_id: Any
    customer_client: Any
    email_address: Any
    access_role: Any
    validate_only: Any

class CustomerOperation(proto.Message):
    update: Any
    update_mask: Any

class CreateCustomerClientResponse(proto.Message):
    resource_name: Any
    invitation_link: Any

class MutateCustomerResponse(proto.Message):
    result: Any

class MutateCustomerResult(proto.Message):
    resource_name: Any
    customer: Any

class ListAccessibleCustomersRequest(proto.Message): ...

class ListAccessibleCustomersResponse(proto.Message):
    resource_names: Any



from typing import Any

import proto

__protobuf__: Any

class ResourceLimitTypeEnum(proto.Message):
    class ResourceLimitType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CAMPAIGNS_PER_CUSTOMER: int
        BASE_CAMPAIGNS_PER_CUSTOMER: int
        EXPERIMENT_CAMPAIGNS_PER_CUSTOMER: int
        HOTEL_CAMPAIGNS_PER_CUSTOMER: int
        SMART_SHOPPING_CAMPAIGNS_PER_CUSTOMER: int
        AD_GROUPS_PER_CAMPAIGN: int
        AD_GROUPS_PER_SHOPPING_CAMPAIGN: int
        AD_GROUPS_PER_HOTEL_CAMPAIGN: int
        REPORTING_AD_GROUPS_PER_LOCAL_CAMPAIGN: int
        REPORTING_AD_GROUPS_PER_APP_CAMPAIGN: int
        MANAGED_AD_GROUPS_PER_SMART_CAMPAIGN: int
        AD_GROUP_CRITERIA_PER_CUSTOMER: int
        BASE_AD_GROUP_CRITERIA_PER_CUSTOMER: int
        EXPERIMENT_AD_GROUP_CRITERIA_PER_CUSTOMER: int
        AD_GROUP_CRITERIA_PER_CAMPAIGN: int
        CAMPAIGN_CRITERIA_PER_CUSTOMER: int
        BASE_CAMPAIGN_CRITERIA_PER_CUSTOMER: int
        EXPERIMENT_CAMPAIGN_CRITERIA_PER_CUSTOMER: int
        WEBPAGE_CRITERIA_PER_CUSTOMER: int
        BASE_WEBPAGE_CRITERIA_PER_CUSTOMER: int
        EXPERIMENT_WEBPAGE_CRITERIA_PER_CUSTOMER: int
        COMBINED_AUDIENCE_CRITERIA_PER_AD_GROUP: int
        CUSTOMER_NEGATIVE_PLACEMENT_CRITERIA_PER_CUSTOMER: int
        CUSTOMER_NEGATIVE_YOUTUBE_CHANNEL_CRITERIA_PER_CUSTOMER: int
        CRITERIA_PER_AD_GROUP: int
        LISTING_GROUPS_PER_AD_GROUP: int
        EXPLICITLY_SHARED_BUDGETS_PER_CUSTOMER: int
        IMPLICITLY_SHARED_BUDGETS_PER_CUSTOMER: int
        COMBINED_AUDIENCE_CRITERIA_PER_CAMPAIGN: int
        NEGATIVE_KEYWORDS_PER_CAMPAIGN: int
        NEGATIVE_PLACEMENTS_PER_CAMPAIGN: int
        GEO_TARGETS_PER_CAMPAIGN: int
        NEGATIVE_IP_BLOCKS_PER_CAMPAIGN: int
        PROXIMITIES_PER_CAMPAIGN: int
        LISTING_SCOPES_PER_SHOPPING_CAMPAIGN: int
        LISTING_SCOPES_PER_NON_SHOPPING_CAMPAIGN: int
        NEGATIVE_KEYWORDS_PER_SHARED_SET: int
        NEGATIVE_PLACEMENTS_PER_SHARED_SET: int
        SHARED_SETS_PER_CUSTOMER_FOR_TYPE_DEFAULT: int
        SHARED_SETS_PER_CUSTOMER_FOR_NEGATIVE_PLACEMENT_LIST_LOWER: int
        HOTEL_ADVANCE_BOOKING_WINDOW_BID_MODIFIERS_PER_AD_GROUP: int
        BIDDING_STRATEGIES_PER_CUSTOMER: int
        BASIC_USER_LISTS_PER_CUSTOMER: int
        LOGICAL_USER_LISTS_PER_CUSTOMER: int
        BASE_AD_GROUP_ADS_PER_CUSTOMER: int
        EXPERIMENT_AD_GROUP_ADS_PER_CUSTOMER: int
        AD_GROUP_ADS_PER_CAMPAIGN: int
        TEXT_AND_OTHER_ADS_PER_AD_GROUP: int
        IMAGE_ADS_PER_AD_GROUP: int
        SHOPPING_SMART_ADS_PER_AD_GROUP: int
        RESPONSIVE_SEARCH_ADS_PER_AD_GROUP: int
        APP_ADS_PER_AD_GROUP: int
        APP_ENGAGEMENT_ADS_PER_AD_GROUP: int
        LOCAL_ADS_PER_AD_GROUP: int
        VIDEO_ADS_PER_AD_GROUP: int
        LEAD_FORM_ASSET_LINKS_PER_CAMPAIGN: int
        VERSIONS_PER_AD: int
        USER_FEEDS_PER_CUSTOMER: int
        SYSTEM_FEEDS_PER_CUSTOMER: int
        FEED_ATTRIBUTES_PER_FEED: int
        FEED_ITEMS_PER_CUSTOMER: int
        CAMPAIGN_FEEDS_PER_CUSTOMER: int
        BASE_CAMPAIGN_FEEDS_PER_CUSTOMER: int
        EXPERIMENT_CAMPAIGN_FEEDS_PER_CUSTOMER: int
        AD_GROUP_FEEDS_PER_CUSTOMER: int
        BASE_AD_GROUP_FEEDS_PER_CUSTOMER: int
        EXPERIMENT_AD_GROUP_FEEDS_PER_CUSTOMER: int
        AD_GROUP_FEEDS_PER_CAMPAIGN: int
        FEED_ITEM_SETS_PER_CUSTOMER: int
        FEED_ITEMS_PER_FEED_ITEM_SET: int
        CAMPAIGN_EXPERIMENTS_PER_CUSTOMER: int
        EXPERIMENT_ARMS_PER_VIDEO_EXPERIMENT: int
        OWNED_LABELS_PER_CUSTOMER: int
        LABELS_PER_CAMPAIGN: int
        LABELS_PER_AD_GROUP: int
        LABELS_PER_AD_GROUP_AD: int
        LABELS_PER_AD_GROUP_CRITERION: int
        TARGET_CUSTOMERS_PER_LABEL: int
        KEYWORD_PLANS_PER_USER_PER_CUSTOMER: int
        KEYWORD_PLAN_AD_GROUP_KEYWORDS_PER_KEYWORD_PLAN: int
        KEYWORD_PLAN_AD_GROUPS_PER_KEYWORD_PLAN: int
        KEYWORD_PLAN_NEGATIVE_KEYWORDS_PER_KEYWORD_PLAN: int
        KEYWORD_PLAN_CAMPAIGNS_PER_KEYWORD_PLAN: int
        CONVERSION_ACTIONS_PER_CUSTOMER: int
        BATCH_JOB_OPERATIONS_PER_JOB: int
        BATCH_JOBS_PER_CUSTOMER: int
        HOTEL_CHECK_IN_DATE_RANGE_BID_MODIFIERS_PER_AD_GROUP: int



from typing import Any

import proto

__protobuf__: Any

class AttributionModelEnum(proto.Message):
    class AttributionModel(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        EXTERNAL: int
        GOOGLE_ADS_LAST_CLICK: int
        GOOGLE_SEARCH_ATTRIBUTION_FIRST_CLICK: int
        GOOGLE_SEARCH_ATTRIBUTION_LINEAR: int
        GOOGLE_SEARCH_ATTRIBUTION_TIME_DECAY: int
        GOOGLE_SEARCH_ATTRIBUTION_POSITION_BASED: int
        GOOGLE_SEARCH_ATTRIBUTION_DATA_DRIVEN: int



from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    google_ads_field_category as google_ads_field_category,
    google_ads_field_data_type as google_ads_field_data_type,
)

__protobuf__: Any

class GoogleAdsField(proto.Message):
    resource_name: Any
    name: Any
    category: Any
    selectable: Any
    filterable: Any
    sortable: Any
    selectable_with: Any
    attribute_resources: Any
    metrics: Any
    segments: Any
    enum_values: Any
    data_type: Any
    type_url: Any
    is_repeated: Any



from typing import Any

import proto

__protobuf__: Any

class GetMediaFileRequest(proto.Message):
    resource_name: Any

class MutateMediaFilesRequest(proto.Message):
    customer_id: Any
    operations: Any
    partial_failure: Any
    validate_only: Any
    response_content_type: Any

class MediaFileOperation(proto.Message):
    create: Any

class MutateMediaFilesResponse(proto.Message):
    partial_failure_error: Any
    results: Any

class MutateMediaFileResult(proto.Message):
    resource_name: Any
    media_file: Any



from typing import Any

import proto
from google.protobuf import field_mask_pb2 as field_mask_pb2
from google.rpc import status_pb2 as status_pb2

__protobuf__: Any

class GetConversionValueRuleRequest(proto.Message):
    resource_name: Any

class MutateConversionValueRulesRequest(proto.Message):
    customer_id: Any
    operations: Any
    partial_failure: Any
    validate_only: Any
    response_content_type: Any

class ConversionValueRuleOperation(proto.Message):
    update_mask: Any
    create: Any
    update: Any
    remove: Any

class MutateConversionValueRulesResponse(proto.Message):
    results: Any
    partial_failure_error: Any

class MutateConversionValueRuleResult(proto.Message):
    resource_name: Any
    conversion_value_rule: Any



from typing import Any

import proto

__protobuf__: Any

class ConversionValueRuleErrorEnum(proto.Message):
    class ConversionValueRuleError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INVALID_GEO_TARGET_CONSTANT: int
        CONFLICTING_INCLUDED_AND_EXCLUDED_GEO_TARGET: int
        CONFLICTING_CONDITIONS: int
        CANNOT_REMOVE_IF_INCLUDED_IN_VALUE_RULE_SET: int
        CONDITION_NOT_ALLOWED: int
        FIELD_MUST_BE_UNSET: int
        CANNOT_PAUSE_UNLESS_VALUE_RULE_SET_IS_PAUSED: int
        UNTARGETABLE_GEO_TARGET: int
        INVALID_AUDIENCE_USER_LIST: int
        INACCESSIBLE_USER_LIST: int
        INVALID_AUDIENCE_USER_INTEREST: int
        CANNOT_ADD_RULE_WITH_STATUS_REMOVED: int



from typing import Any

import proto

from google.ads.googleads.v7.common.types import (
    keyword_plan_common as keyword_plan_common,
)

__protobuf__: Any

class GetKeywordPlanRequest(proto.Message):
    resource_name: Any

class MutateKeywordPlansRequest(proto.Message):
    customer_id: Any
    operations: Any
    partial_failure: Any
    validate_only: Any

class KeywordPlanOperation(proto.Message):
    update_mask: Any
    create: Any
    update: Any
    remove: Any

class MutateKeywordPlansResponse(proto.Message):
    partial_failure_error: Any
    results: Any

class MutateKeywordPlansResult(proto.Message):
    resource_name: Any

class GenerateForecastCurveRequest(proto.Message):
    keyword_plan: Any

class GenerateForecastCurveResponse(proto.Message):
    campaign_forecast_curves: Any

class GenerateForecastTimeSeriesRequest(proto.Message):
    keyword_plan: Any

class GenerateForecastTimeSeriesResponse(proto.Message):
    weekly_time_series_forecasts: Any

class GenerateForecastMetricsRequest(proto.Message):
    keyword_plan: Any

class GenerateForecastMetricsResponse(proto.Message):
    campaign_forecasts: Any
    ad_group_forecasts: Any
    keyword_forecasts: Any

class KeywordPlanCampaignForecast(proto.Message):
    keyword_plan_campaign: Any
    campaign_forecast: Any

class KeywordPlanAdGroupForecast(proto.Message):
    keyword_plan_ad_group: Any
    ad_group_forecast: Any

class KeywordPlanKeywordForecast(proto.Message):
    keyword_plan_ad_group_keyword: Any
    keyword_forecast: Any

class KeywordPlanCampaignForecastCurve(proto.Message):
    keyword_plan_campaign: Any
    max_cpc_bid_forecast_curve: Any

class KeywordPlanMaxCpcBidForecastCurve(proto.Message):
    max_cpc_bid_forecasts: Any

class KeywordPlanMaxCpcBidForecast(proto.Message):
    max_cpc_bid_micros: Any
    max_cpc_bid_forecast: Any

class KeywordPlanWeeklyTimeSeriesForecast(proto.Message):
    keyword_plan_campaign: Any
    weekly_forecasts: Any

class KeywordPlanWeeklyForecast(proto.Message):
    start_date: Any
    forecast: Any

class ForecastMetrics(proto.Message):
    impressions: Any
    ctr: Any
    average_cpc: Any
    clicks: Any
    cost_micros: Any

class GenerateHistoricalMetricsRequest(proto.Message):
    keyword_plan: Any
    aggregate_metrics: Any
    historical_metrics_options: Any

class GenerateHistoricalMetricsResponse(proto.Message):
    metrics: Any
    aggregate_metric_results: Any

class KeywordPlanKeywordHistoricalMetrics(proto.Message):
    search_query: Any
    close_variants: Any
    keyword_metrics: Any



from typing import Any

import proto

__protobuf__: Any

class CollectionSizeErrorEnum(proto.Message):
    class CollectionSizeError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        TOO_FEW: int
        TOO_MANY: int



from typing import Any

import proto

__protobuf__: Any

class FieldMaskErrorEnum(proto.Message):
    class FieldMaskError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        FIELD_MASK_MISSING: int
        FIELD_MASK_NOT_ALLOWED: int
        FIELD_NOT_FOUND: int
        FIELD_HAS_SUBFIELDS: int



from typing import Any

import proto

__protobuf__: Any

class LanguageCodeErrorEnum(proto.Message):
    class LanguageCodeError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        LANGUAGE_CODE_NOT_FOUND: int
        INVALID_LANGUAGE_CODE: int



from typing import Any

import proto

from google.ads.googleads.v8.common.types import dates as dates
from google.ads.googleads.v8.enums.types import invoice_type as invoice_type

__protobuf__: Any

class Invoice(proto.Message):
    class AccountBudgetSummary(proto.Message):
        customer: Any
        customer_descriptive_name: Any
        account_budget: Any
        account_budget_name: Any
        purchase_order_number: Any
        subtotal_amount_micros: Any
        tax_amount_micros: Any
        total_amount_micros: Any
        billable_activity_date_range: Any
    resource_name: Any
    id: Any
    type_: Any
    billing_setup: Any
    payments_account_id: Any
    payments_profile_id: Any
    issue_date: Any
    due_date: Any
    service_date_range: Any
    currency_code: Any
    adjustments_subtotal_amount_micros: Any
    adjustments_tax_amount_micros: Any
    adjustments_total_amount_micros: Any
    regulatory_costs_subtotal_amount_micros: Any
    regulatory_costs_tax_amount_micros: Any
    regulatory_costs_total_amount_micros: Any
    subtotal_amount_micros: Any
    tax_amount_micros: Any
    total_amount_micros: Any
    corrected_invoice: Any
    replaced_invoices: Any
    pdf_url: Any
    account_budget_summaries: Any



from typing import Any

import proto

__protobuf__: Any

class CampaignErrorEnum(proto.Message):
    class CampaignError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CANNOT_TARGET_CONTENT_NETWORK: int
        CANNOT_TARGET_SEARCH_NETWORK: int
        CANNOT_TARGET_SEARCH_NETWORK_WITHOUT_GOOGLE_SEARCH: int
        CANNOT_TARGET_GOOGLE_SEARCH_FOR_CPM_CAMPAIGN: int
        CAMPAIGN_MUST_TARGET_AT_LEAST_ONE_NETWORK: int
        CANNOT_TARGET_PARTNER_SEARCH_NETWORK: int
        CANNOT_TARGET_CONTENT_NETWORK_ONLY_WITH_CRITERIA_LEVEL_BIDDING_STRATEGY: int
        CAMPAIGN_DURATION_MUST_CONTAIN_ALL_RUNNABLE_TRIALS: int
        CANNOT_MODIFY_FOR_TRIAL_CAMPAIGN: int
        DUPLICATE_CAMPAIGN_NAME: int
        INCOMPATIBLE_CAMPAIGN_FIELD: int
        INVALID_CAMPAIGN_NAME: int
        INVALID_AD_SERVING_OPTIMIZATION_STATUS: int
        INVALID_TRACKING_URL: int
        CANNOT_SET_BOTH_TRACKING_URL_TEMPLATE_AND_TRACKING_SETTING: int
        MAX_IMPRESSIONS_NOT_IN_RANGE: int
        TIME_UNIT_NOT_SUPPORTED: int
        INVALID_OPERATION_IF_SERVING_STATUS_HAS_ENDED: int
        BUDGET_CANNOT_BE_SHARED: int
        CAMPAIGN_CANNOT_USE_SHARED_BUDGET: int
        CANNOT_CHANGE_BUDGET_ON_CAMPAIGN_WITH_TRIALS: int
        CAMPAIGN_LABEL_DOES_NOT_EXIST: int
        CAMPAIGN_LABEL_ALREADY_EXISTS: int
        MISSING_SHOPPING_SETTING: int
        INVALID_SHOPPING_SALES_COUNTRY: int
        ADVERTISING_CHANNEL_TYPE_NOT_AVAILABLE_FOR_ACCOUNT_TYPE: int
        INVALID_ADVERTISING_CHANNEL_SUB_TYPE: int
        AT_LEAST_ONE_CONVERSION_MUST_BE_SELECTED: int
        CANNOT_SET_AD_ROTATION_MODE: int
        CANNOT_MODIFY_START_DATE_IF_ALREADY_STARTED: int
        CANNOT_SET_DATE_TO_PAST: int
        MISSING_HOTEL_CUSTOMER_LINK: int
        INVALID_HOTEL_CUSTOMER_LINK: int
        MISSING_HOTEL_SETTING: int
        CANNOT_USE_SHARED_CAMPAIGN_BUDGET_WHILE_PART_OF_CAMPAIGN_GROUP: int
        APP_NOT_FOUND: int
        SHOPPING_ENABLE_LOCAL_NOT_SUPPORTED_FOR_CAMPAIGN_TYPE: int
        MERCHANT_NOT_ALLOWED_FOR_COMPARISON_LISTING_ADS: int
        INSUFFICIENT_APP_INSTALLS_COUNT: int
        SENSITIVE_CATEGORY_APP: int
        HEC_AGREEMENT_REQUIRED: int
        PAYMENT_MODE_NOT_COMPATIBLE_WITH_VIEW_THROUGH_CONVERSION: int
        INVALID_EXCLUDED_PARENT_ASSET_FIELD_TYPE: int



from typing import Any

import proto

__protobuf__: Any

class UserListLogicalRuleOperatorEnum(proto.Message):
    class UserListLogicalRuleOperator(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ALL: int
        ANY: int
        NONE: int



from typing import Any

import proto

__protobuf__: Any

class UserListErrorEnum(proto.Message):
    class UserListError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        EXTERNAL_REMARKETING_USER_LIST_MUTATE_NOT_SUPPORTED: int
        CONCRETE_TYPE_REQUIRED: int
        CONVERSION_TYPE_ID_REQUIRED: int
        DUPLICATE_CONVERSION_TYPES: int
        INVALID_CONVERSION_TYPE: int
        INVALID_DESCRIPTION: int
        INVALID_NAME: int
        INVALID_TYPE: int
        CAN_NOT_ADD_LOGICAL_LIST_AS_LOGICAL_LIST_OPERAND: int
        INVALID_USER_LIST_LOGICAL_RULE_OPERAND: int
        NAME_ALREADY_USED: int
        NEW_CONVERSION_TYPE_NAME_REQUIRED: int
        CONVERSION_TYPE_NAME_ALREADY_USED: int
        OWNERSHIP_REQUIRED_FOR_SET: int
        USER_LIST_MUTATE_NOT_SUPPORTED: int
        INVALID_RULE: int
        INVALID_DATE_RANGE: int
        CAN_NOT_MUTATE_SENSITIVE_USERLIST: int
        MAX_NUM_RULEBASED_USERLISTS: int
        CANNOT_MODIFY_BILLABLE_RECORD_COUNT: int
        APP_ID_NOT_SET: int
        USERLIST_NAME_IS_RESERVED_FOR_SYSTEM_LIST: int
        ADVERTISER_NOT_ON_ALLOWLIST_FOR_USING_UPLOADED_DATA: int
        RULE_TYPE_IS_NOT_SUPPORTED: int
        CAN_NOT_ADD_A_SIMILAR_USERLIST_AS_LOGICAL_LIST_OPERAND: int
        CAN_NOT_MIX_CRM_BASED_IN_LOGICAL_LIST_WITH_OTHER_LISTS: int



from typing import Any

import proto
from google.protobuf import field_mask_pb2 as field_mask_pb2

from google.ads.googleads.v8.resources.types import (
    customer_user_access as customer_user_access,
)

__protobuf__: Any

class GetCustomerUserAccessRequest(proto.Message):
    resource_name: Any

class MutateCustomerUserAccessRequest(proto.Message):
    customer_id: Any
    operation: Any

class CustomerUserAccessOperation(proto.Message):
    update_mask: Any
    update: Any
    remove: Any

class MutateCustomerUserAccessResponse(proto.Message):
    result: Any

class MutateCustomerUserAccessResult(proto.Message):
    resource_name: Any



from typing import Any

import proto

__protobuf__: Any

class FeedAttributeTypeEnum(proto.Message):
    class FeedAttributeType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INT64: int
        DOUBLE: int
        STRING: int
        BOOLEAN: int
        URL: int
        DATE_TIME: int
        INT64_LIST: int
        DOUBLE_LIST: int
        STRING_LIST: int
        BOOLEAN_LIST: int
        URL_LIST: int
        DATE_TIME_LIST: int
        PRICE: int



from typing import Any, Callable, Iterable, Sequence, Tuple

from google.rpc import status_pb2 as status

from google.ads.googleads.v7.services.types import (
    campaign_experiment_service as campaign_experiment_service,
)

class ListCampaignExperimentAsyncErrorsPager:
    def __init__(
        self,
        method: Callable[
            ..., campaign_experiment_service.ListCampaignExperimentAsyncErrorsResponse
        ],
        request: campaign_experiment_service.ListCampaignExperimentAsyncErrorsRequest,
        response: campaign_experiment_service.ListCampaignExperimentAsyncErrorsResponse,
        metadata: Sequence[Tuple[str, str]] = ...,
    ) -> None: ...
    def __getattr__(self, name: str) -> Any: ...
    @property
    def pages(
        self,
    ) -> Iterable[
        campaign_experiment_service.ListCampaignExperimentAsyncErrorsResponse
    ]: ...
    def __iter__(self) -> Iterable[status.Status]: ...



from typing import Any

import proto

__protobuf__: Any

class LocationGroupRadiusUnitsEnum(proto.Message):
    class LocationGroupRadiusUnits(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        METERS: int
        MILES: int
        MILLI_MILES: int



from typing import Any

import proto

__protobuf__: Any

class KeywordPlanConceptGroupTypeEnum(proto.Message):
    class KeywordPlanConceptGroupType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        BRAND: int
        OTHER_BRANDS: int
        NON_BRAND: int



from .base import (
    FeedPlaceholderViewServiceTransport as FeedPlaceholderViewServiceTransport,
)
from .grpc import (
    FeedPlaceholderViewServiceGrpcTransport as FeedPlaceholderViewServiceGrpcTransport,
)



from typing import Any

import proto

__protobuf__: Any

class NotAllowlistedErrorEnum(proto.Message):
    class NotAllowlistedError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CUSTOMER_NOT_ALLOWLISTED_FOR_THIS_FEATURE: int



from typing import Any, Dict, Optional, Union

import proto
from google.oauth2.credentials import Credentials
from google.protobuf.message import Message
from typing_extensions import Literal

from google.ads.googleads.config import _ConfigDataUnparsed

_V7 = Literal["v7"]
_V8 = Literal["v8"]
_V = Union[_V7, _V8]

class GoogleAdsClient:
    credentials: Credentials
    developer_token: str
    endpoint: Optional[str]
    login_customer_id: Optional[str]
    linked_customer_id: Optional[str]
    version: Optional[str]
    http_proxy: Optional[str]
    use_proto_plus: bool
    enums: Any  # TODO
    @classmethod
    def copy_from(
        cls,
        destination: Union[proto.Message, Message],
        origin: Union[proto.Message, Message],
    ) -> None: ...
    @classmethod
    def load_from_env(cls, version: Optional[str] = ...) -> GoogleAdsClient: ...
    @classmethod
    def load_from_string(
        cls, yaml_str: str, version: Optional[str] = ...
    ) -> GoogleAdsClient: ...
    @classmethod
    def load_from_storage(
        cls, path: Optional[str] = ..., version: Optional[str] = ...
    ) -> GoogleAdsClient: ...
    @classmethod
    def load_from_dict(
        cls, config_dict: _ConfigDataUnparsed, version: Optional[str] = ...
    ) -> GoogleAdsClient: ...
    def __init__(
        self,
        credentials: Credentials,
        developer_token: str,
        endpoint: Optional[str] = ...,
        login_customer_id: Optional[str] = ...,
        logging_config: Optional[Dict[Any, Any]] = ...,
        linked_customer_id: Optional[str] = ...,
        version: Optional[str] = ...,
        http_proxy: Optional[str] = ...,
        use_proto_plus: bool = ...,
    ) -> None: ...
    def get_type(cls, name: str, version: _V = ...) -> Any: ...
    def get_service(self, name: str, version: _V = ...) -> Any: ...



from typing import Any

import proto

__protobuf__: Any

class ConversionActionTypeEnum(proto.Message):
    class ConversionActionType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        AD_CALL: int
        CLICK_TO_CALL: int
        GOOGLE_PLAY_DOWNLOAD: int
        GOOGLE_PLAY_IN_APP_PURCHASE: int
        UPLOAD_CALLS: int
        UPLOAD_CLICKS: int
        WEBPAGE: int
        WEBSITE_CALL: int
        STORE_SALES_DIRECT_UPLOAD: int
        STORE_SALES: int
        FIREBASE_ANDROID_FIRST_OPEN: int
        FIREBASE_ANDROID_IN_APP_PURCHASE: int
        FIREBASE_ANDROID_CUSTOM: int
        FIREBASE_IOS_FIRST_OPEN: int
        FIREBASE_IOS_IN_APP_PURCHASE: int
        FIREBASE_IOS_CUSTOM: int
        THIRD_PARTY_APP_ANALYTICS_ANDROID_FIRST_OPEN: int
        THIRD_PARTY_APP_ANALYTICS_ANDROID_IN_APP_PURCHASE: int
        THIRD_PARTY_APP_ANALYTICS_ANDROID_CUSTOM: int
        THIRD_PARTY_APP_ANALYTICS_IOS_FIRST_OPEN: int
        THIRD_PARTY_APP_ANALYTICS_IOS_IN_APP_PURCHASE: int
        THIRD_PARTY_APP_ANALYTICS_IOS_CUSTOM: int
        ANDROID_APP_PRE_REGISTRATION: int
        ANDROID_INSTALLS_ALL_OTHER_APPS: int
        FLOODLIGHT_ACTION: int
        FLOODLIGHT_TRANSACTION: int
        GOOGLE_HOSTED: int
        LEAD_FORM_SUBMIT: int
        SALESFORCE: int
        SEARCH_ADS_360: int
        SMART_CAMPAIGN_AD_CLICKS_TO_CALL: int
        SMART_CAMPAIGN_MAP_CLICKS_TO_CALL: int
        SMART_CAMPAIGN_MAP_DIRECTIONS: int
        SMART_CAMPAIGN_TRACKED_CALLS: int
        STORE_VISITS: int



from typing import Any

import proto

__protobuf__: Any

class CampaignBudgetErrorEnum(proto.Message):
    class CampaignBudgetError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CAMPAIGN_BUDGET_CANNOT_BE_SHARED: int
        CAMPAIGN_BUDGET_REMOVED: int
        CAMPAIGN_BUDGET_IN_USE: int
        CAMPAIGN_BUDGET_PERIOD_NOT_AVAILABLE: int
        CANNOT_MODIFY_FIELD_OF_IMPLICITLY_SHARED_CAMPAIGN_BUDGET: int
        CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_IMPLICITLY_SHARED: int
        CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED_WITHOUT_NAME: int
        CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED: int
        CANNOT_USE_IMPLICITLY_SHARED_CAMPAIGN_BUDGET_WITH_MULTIPLE_CAMPAIGNS: int
        DUPLICATE_NAME: int
        MONEY_AMOUNT_IN_WRONG_CURRENCY: int
        MONEY_AMOUNT_LESS_THAN_CURRENCY_MINIMUM_CPC: int
        MONEY_AMOUNT_TOO_LARGE: int
        NEGATIVE_MONEY_AMOUNT: int
        NON_MULTIPLE_OF_MINIMUM_CURRENCY_UNIT: int
        TOTAL_BUDGET_AMOUNT_MUST_BE_UNSET_FOR_BUDGET_PERIOD_DAILY: int



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    app_url_operating_system_type as app_url_operating_system_type,
)

__protobuf__: Any

class FinalAppUrl(proto.Message):
    os_type: Any
    url: Any



from typing import Any

import proto

__protobuf__: Any

class BidModifierSourceEnum(proto.Message):
    class BidModifierSource(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CAMPAIGN: int
        AD_GROUP: int



from typing import Any

import proto

__protobuf__: Any

class ConversionActionCountingTypeEnum(proto.Message):
    class ConversionActionCountingType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ONE_PER_CLICK: int
        MANY_PER_CLICK: int



from typing import Any

import proto

__protobuf__: Any

class UserListCombinedRuleOperatorEnum(proto.Message):
    class UserListCombinedRuleOperator(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        AND: int
        AND_NOT: int



from typing import Any

import proto

__protobuf__: Any

class CampaignDraftErrorEnum(proto.Message):
    class CampaignDraftError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        DUPLICATE_DRAFT_NAME: int
        INVALID_STATUS_TRANSITION_FROM_REMOVED: int
        INVALID_STATUS_TRANSITION_FROM_PROMOTED: int
        INVALID_STATUS_TRANSITION_FROM_PROMOTE_FAILED: int
        CUSTOMER_CANNOT_CREATE_DRAFT: int
        CAMPAIGN_CANNOT_CREATE_DRAFT: int
        INVALID_DRAFT_CHANGE: int
        INVALID_STATUS_TRANSITION: int
        MAX_NUMBER_OF_DRAFTS_PER_CAMPAIGN_REACHED: int
        LIST_ERRORS_FOR_PROMOTED_DRAFT_ONLY: int



from typing import Any

import proto

__protobuf__: Any

class MediaBundleErrorEnum(proto.Message):
    class MediaBundleError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        BAD_REQUEST: int
        DOUBLECLICK_BUNDLE_NOT_ALLOWED: int
        EXTERNAL_URL_NOT_ALLOWED: int
        FILE_TOO_LARGE: int
        GOOGLE_WEB_DESIGNER_ZIP_FILE_NOT_PUBLISHED: int
        INVALID_INPUT: int
        INVALID_MEDIA_BUNDLE: int
        INVALID_MEDIA_BUNDLE_ENTRY: int
        INVALID_MIME_TYPE: int
        INVALID_PATH: int
        INVALID_URL_REFERENCE: int
        MEDIA_DATA_TOO_LARGE: int
        MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY: int
        SERVER_ERROR: int
        STORAGE_ERROR: int
        SWIFFY_BUNDLE_NOT_ALLOWED: int
        TOO_MANY_FILES: int
        UNEXPECTED_SIZE: int
        UNSUPPORTED_GOOGLE_WEB_DESIGNER_ENVIRONMENT: int
        UNSUPPORTED_HTML5_FEATURE: int
        URL_IN_MEDIA_BUNDLE_NOT_SSL_COMPLIANT: int
        CUSTOM_EXIT_NOT_ALLOWED: int



from typing import Any

import proto

__protobuf__: Any

class HotelRateTypeEnum(proto.Message):
    class HotelRateType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        UNAVAILABLE: int
        PUBLIC_RATE: int
        QUALIFIED_RATE: int
        PRIVATE_RATE: int



from typing import Any

import proto

__protobuf__: Any

class CriterionCategoryLocaleAvailabilityModeEnum(proto.Message):
    class CriterionCategoryLocaleAvailabilityMode(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ALL_LOCALES: int
        COUNTRY_AND_ALL_LANGUAGES: int
        LANGUAGE_AND_ALL_COUNTRIES: int
        COUNTRY_AND_LANGUAGE: int



from typing import Any

import proto

__protobuf__: Any

class HotelPriceBucketEnum(proto.Message):
    class HotelPriceBucket(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        LOWEST_UNIQUE: int
        LOWEST_TIED: int
        NOT_LOWEST: int
        ONLY_PARTNER_SHOWN: int



from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    tracking_code_page_format as tracking_code_page_format,
    tracking_code_type as tracking_code_type,
)

__protobuf__: Any

class TagSnippet(proto.Message):
    type_: Any
    page_format: Any
    global_site_tag: Any
    event_snippet: Any



from typing import Any

import proto

__protobuf__: Any

class ProductChannelExclusivityEnum(proto.Message):
    class ProductChannelExclusivity(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        SINGLE_CHANNEL: int
        MULTI_CHANNEL: int



from typing import Any

import proto

from google.ads.googleads.v7.common.types import tag_snippet as tag_snippet
from google.ads.googleads.v7.enums.types import (
    conversion_action_category as conversion_action_category,
    conversion_action_counting_type as conversion_action_counting_type,
    conversion_action_status as conversion_action_status,
    conversion_action_type as conversion_action_type,
)

__protobuf__: Any

class ConversionAction(proto.Message):
    class AttributionModelSettings(proto.Message):
        attribution_model: Any
        data_driven_model_status: Any
    class ValueSettings(proto.Message):
        default_value: Any
        default_currency_code: Any
        always_use_default_value: Any
    class FirebaseSettings(proto.Message):
        event_name: Any
        project_id: Any
    class ThirdPartyAppAnalyticsSettings(proto.Message):
        event_name: Any
        provider_name: Any
    resource_name: Any
    id: Any
    name: Any
    status: Any
    type_: Any
    category: Any
    owner_customer: Any
    include_in_conversions_metric: Any
    click_through_lookback_window_days: Any
    view_through_lookback_window_days: Any
    value_settings: Any
    counting_type: Any
    attribution_model_settings: Any
    tag_snippets: Any
    phone_call_duration_seconds: Any
    app_id: Any
    mobile_app_vendor: Any
    firebase_settings: Any
    third_party_app_analytics_settings: Any



from typing import Any

import proto

from google.ads.googleads.v7.common.types import dates as dates
from google.ads.googleads.v7.enums.types import (
    keyword_plan_forecast_interval as keyword_plan_forecast_interval,
)

__protobuf__: Any

class KeywordPlan(proto.Message):
    resource_name: Any
    id: Any
    name: Any
    forecast_period: Any

class KeywordPlanForecastPeriod(proto.Message):
    date_interval: Any
    date_range: Any



from typing import Any

import proto

__protobuf__: Any

class AdGroupAdErrorEnum(proto.Message):
    class AdGroupAdError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        AD_GROUP_AD_LABEL_DOES_NOT_EXIST: int
        AD_GROUP_AD_LABEL_ALREADY_EXISTS: int
        AD_NOT_UNDER_ADGROUP: int
        CANNOT_OPERATE_ON_REMOVED_ADGROUPAD: int
        CANNOT_CREATE_DEPRECATED_ADS: int
        CANNOT_CREATE_TEXT_ADS: int
        EMPTY_FIELD: int
        RESOURCE_REFERENCED_IN_MULTIPLE_OPS: int
        AD_TYPE_CANNOT_BE_PAUSED: int
        AD_TYPE_CANNOT_BE_REMOVED: int



from typing import Any

import proto

__protobuf__: Any

class MatchingFunctionOperatorEnum(proto.Message):
    class MatchingFunctionOperator(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        IN: int
        IDENTITY: int
        EQUALS: int
        AND: int
        CONTAINS_ANY: int



from .base import (
    CampaignSimulationServiceTransport as CampaignSimulationServiceTransport,
)
from .grpc import (
    CampaignSimulationServiceGrpcTransport as CampaignSimulationServiceGrpcTransport,
)



from typing import Any

import proto

__protobuf__: Any

class OperatingSystemVersionOperatorTypeEnum(proto.Message):
    class OperatingSystemVersionOperatorType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        EQUALS_TO: int
        GREATER_THAN_EQUALS_TO: int



from typing import Any

import proto
from google.protobuf import field_mask_pb2 as field_mask_pb2
from google.rpc import status_pb2 as status_pb2

__protobuf__: Any

class GetAssetRequest(proto.Message):
    resource_name: Any

class MutateAssetsRequest(proto.Message):
    customer_id: Any
    operations: Any
    partial_failure: Any
    response_content_type: Any
    validate_only: Any

class AssetOperation(proto.Message):
    update_mask: Any
    create: Any
    update: Any

class MutateAssetsResponse(proto.Message):
    partial_failure_error: Any
    results: Any

class MutateAssetResult(proto.Message):
    resource_name: Any
    asset: Any



from typing import Any

import proto

__protobuf__: Any

class MinuteOfHourEnum(proto.Message):
    class MinuteOfHour(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ZERO: int
        FIFTEEN: int
        THIRTY: int
        FORTY_FIVE: int



from typing import Any

import proto

__protobuf__: Any

class CampaignExperimentTrafficSplitTypeEnum(proto.Message):
    class CampaignExperimentTrafficSplitType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        RANDOM_QUERY: int
        COOKIE: int



from typing import Any

import proto

__protobuf__: Any

class KeywordPlanAdGroupErrorEnum(proto.Message):
    class KeywordPlanAdGroupError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INVALID_NAME: int
        DUPLICATE_NAME: int



from .base import (
    AccessibleBiddingStrategyServiceTransport as AccessibleBiddingStrategyServiceTransport,
)
from .grpc import (
    AccessibleBiddingStrategyServiceGrpcTransport as AccessibleBiddingStrategyServiceGrpcTransport,
)



from typing import Any

import proto

__protobuf__: Any

class FeedMappingErrorEnum(proto.Message):
    class FeedMappingError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INVALID_PLACEHOLDER_FIELD: int
        INVALID_CRITERION_FIELD: int
        INVALID_PLACEHOLDER_TYPE: int
        INVALID_CRITERION_TYPE: int
        NO_ATTRIBUTE_FIELD_MAPPINGS: int
        FEED_ATTRIBUTE_TYPE_MISMATCH: int
        CANNOT_OPERATE_ON_MAPPINGS_FOR_SYSTEM_GENERATED_FEED: int
        MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_TYPE: int
        MULTIPLE_MAPPINGS_FOR_CRITERION_TYPE: int
        MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_FIELD: int
        MULTIPLE_MAPPINGS_FOR_CRITERION_FIELD: int
        UNEXPECTED_ATTRIBUTE_FIELD_MAPPINGS: int
        LOCATION_PLACEHOLDER_ONLY_FOR_PLACES_FEEDS: int
        CANNOT_MODIFY_MAPPINGS_FOR_TYPED_FEED: int
        INVALID_PLACEHOLDER_TYPE_FOR_NON_SYSTEM_GENERATED_FEED: int
        INVALID_PLACEHOLDER_TYPE_FOR_SYSTEM_GENERATED_FEED_TYPE: int
        ATTRIBUTE_FIELD_MAPPING_MISSING_FIELD: int



from typing import Any

import proto

from google.ads.googleads.v8.common.types import criteria as criteria
from google.ads.googleads.v8.enums.types import criterion_type as criterion_type

__protobuf__: Any

class CustomerNegativeCriterion(proto.Message):
    resource_name: Any
    id: Any
    type_: Any
    content_label: Any
    mobile_application: Any
    mobile_app_category: Any
    placement: Any
    youtube_video: Any
    youtube_channel: Any



from typing import Any

import proto

from google.ads.googleads.v7.common.types import criteria as criteria

__protobuf__: Any

class Segments(proto.Message):
    ad_destination_type: Any
    ad_network_type: Any
    budget_campaign_association_status: Any
    click_type: Any
    conversion_action: Any
    conversion_action_category: Any
    conversion_action_name: Any
    conversion_adjustment: Any
    conversion_attribution_event_type: Any
    conversion_lag_bucket: Any
    conversion_or_adjustment_lag_bucket: Any
    date: Any
    day_of_week: Any
    device: Any
    external_conversion_source: Any
    geo_target_airport: Any
    geo_target_canton: Any
    geo_target_city: Any
    geo_target_country: Any
    geo_target_county: Any
    geo_target_district: Any
    geo_target_metro: Any
    geo_target_most_specific_location: Any
    geo_target_postal_code: Any
    geo_target_province: Any
    geo_target_region: Any
    geo_target_state: Any
    hotel_booking_window_days: Any
    hotel_center_id: Any
    hotel_check_in_date: Any
    hotel_check_in_day_of_week: Any
    hotel_city: Any
    hotel_class: Any
    hotel_country: Any
    hotel_date_selection_type: Any
    hotel_length_of_stay: Any
    hotel_rate_rule_id: Any
    hotel_rate_type: Any
    hotel_price_bucket: Any
    hotel_state: Any
    hour: Any
    interaction_on_this_extension: Any
    keyword: Any
    month: Any
    month_of_year: Any
    partner_hotel_id: Any
    placeholder_type: Any
    product_aggregator_id: Any
    product_bidding_category_level1: Any
    product_bidding_category_level2: Any
    product_bidding_category_level3: Any
    product_bidding_category_level4: Any
    product_bidding_category_level5: Any
    product_brand: Any
    product_channel: Any
    product_channel_exclusivity: Any
    product_condition: Any
    product_country: Any
    product_custom_attribute0: Any
    product_custom_attribute1: Any
    product_custom_attribute2: Any
    product_custom_attribute3: Any
    product_custom_attribute4: Any
    product_item_id: Any
    product_language: Any
    product_merchant_id: Any
    product_store_id: Any
    product_title: Any
    product_type_l1: Any
    product_type_l2: Any
    product_type_l3: Any
    product_type_l4: Any
    product_type_l5: Any
    quarter: Any
    search_engine_results_page_type: Any
    search_term_match_type: Any
    slot: Any
    webpage: Any
    week: Any
    year: Any
    sk_ad_network_conversion_value: Any

class Keyword(proto.Message):
    ad_group_criterion: Any
    info: Any

class BudgetCampaignAssociationStatus(proto.Message):
    campaign: Any
    status: Any
